# Contributions

This section is for contributed work that can be used with hls4ml that is potentially useful to a wider audience. Examples include implementations for custom layer types for use with the Extensions API.

## How to structure contributions

The best way to structure a contribution is to make a directory for the contribution, with a README inside to explain what it is and how to use it. If possible there should be an example script demonstrating how to use it. We should be able to validate that the code works.
